==> haskell-abstract-par-0.3.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-par
version: 0.3.3
id: abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
key: abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
license: BSD-3-Clause
copyright: (c) Ryan Newton 2011-2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Type classes generalizing the functionality of the '\''monad-par'\'' library.
description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.
    .
    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.
category: Control,Parallelism,Monads
abi: 3c7ebe7f8f8a713ba55857a5c0914fc8
exposed: True
exposed-modules:
    Control.Monad.Par.Class Control.Monad.Par.Unsafe
import-dirs: /usr/lib/ghc-8.4.3/site-local/abstract-par-0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/abstract-par-0.3.3
hs-libraries: HSabstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock
haddock-html: /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-par-0.3.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-par
version: 0.3.3
id: abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj
key: abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj
license: BSD-3-Clause
copyright: (c) Ryan Newton 2011-2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Type classes generalizing the functionality of the '\''monad-par'\'' library.
description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.
    .
    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.
category: Control,Parallelism,Monads
abi: fcf227c96bed096632bdea16cc58fccb
exposed: True
exposed-modules:
    Control.Monad.Par.Class Control.Monad.Par.Unsafe
import-dirs: /usr/lib/ghc-8.6.1/site-local/abstract-par-0.3.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/abstract-par-0.3.3
hs-libraries: HSabstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj
depends:
    base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock
haddock-html: /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
